<?php

namespace Liteerp\Patient\Policies;

use Litepie\User\Contracts\UserPolicy;
use Liteerp\Patient\Models\Patient;

class PatientPolicy
{

    /**
     * Determine if the given user can view the patient.
     *
     * @param UserPolicy $user
     * @param Patient $patient
     *
     * @return bool
     */
    public function view(UserPolicy $user, Patient $patient)
    {
        if ($user->canDo('patient.patient.view') && $user->isAdmin()) {
            return true;
        }

        return $patient->user_id == user_id() && $patient->user_type == user_type();
    }

    /**
     * Determine if the given user can create a patient.
     *
     * @param UserPolicy $user
     * @param Patient $patient
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('patient.patient.create');
    }

    /**
     * Determine if the given user can update the given patient.
     *
     * @param UserPolicy $user
     * @param Patient $patient
     *
     * @return bool
     */
    public function update(UserPolicy $user, Patient $patient)
    {
        if ($user->canDo('patient.patient.edit') && $user->isAdmin()) {
            return true;
        }

        return $patient->user_id == user_id() && $patient->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given patient.
     *
     * @param UserPolicy $user
     * @param Patient $patient
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Patient $patient)
    {
        return $patient->user_id == user_id() && $patient->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given patient.
     *
     * @param UserPolicy $user
     * @param Patient $patient
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Patient $patient)
    {
        if ($user->canDo('patient.patient.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given patient.
     *
     * @param UserPolicy $user
     * @param Patient $patient
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Patient $patient)
    {
        if ($user->canDo('patient.patient.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
